@@ -7,6 +7,7 @@ from jenkins_job_manager.core import JenkinsJobManager
 import click
 import logging
 import os
+import typing
 
 logging.basicConfig(level=logging.INFO)
 log = logging.getLogger("jjm")
@@ -14,6 +15,11 @@ log = logging.getLogger("jjm")
 HERE = os.path.dirname(os.path.realpath(__file__))
 
 
+click_option_target = click.option(
+    "--target", default=None, multiple=True, help="job name glob to target",
+)
+
+
 @click.group()
 @click.option("--debug", "-d", is_flag=True)
 @click.option("--working-dir", "-C", default=None, help="change to this directory ")
@@ -51,7 +57,7 @@ def jjm_login(obj: JenkinsJobManager):
     jurl = jconf.url
     username, password = jconf.username, jconf.password
     if username and password:
-        click.secho(f"Auth already configured for this jenkins!", fg="red")
+        click.secho("Auth already configured for this jenkins!", fg="red")
         click.secho(f"{jconf}", fg="white")
         click.confirm("overwrite?", abort=True)
 
@@ -75,7 +81,7 @@ def jjm_login(obj: JenkinsJobManager):
         click.secho(f"Success! Saving to {jconf.user_conf_path}", fg="green")
         jconf.update_user_conf_auth(username, password)
     else:
-        click.secho(f"Bad Authentication, try again.", fg="red")
+        click.secho("Bad Authentication, try again.", fg="red")
         raise click.exceptions.Exit(2)
 
 
@@ -122,7 +128,7 @@ def handle_plan_report(obj: JenkinsJobManager, use_pager=True) -> bool:
         else:
             return line
 
-    if obj.detected_changes():
+    if obj.detected_changes() is True:
         gen_lines = map(output_format, obj.plan_report())
         if use_pager is True:
             click.echo_via_pager(gen_lines)
@@ -138,25 +144,27 @@ def handle_plan_report(obj: JenkinsJobManager, use_pager=True) -> bool:
 
 @jjm.command(name="plan")
 @click.option("--skip-pager", is_flag=True)
+@click_option_target
 @click.pass_obj
-def jjm_plan(obj: JenkinsJobManager, skip_pager: bool):
+def jjm_plan(obj: JenkinsJobManager, skip_pager: bool, target: typing.List[str]):
     """check for changes"""
     check_auth(obj)
-    obj.gather()
+    obj.gather(target)
     handle_validation_errors(obj)
     changes = handle_plan_report(obj, use_pager=not skip_pager)
-    if changes:
+    if changes is True:
         raise click.exceptions.Exit(2)
 
 
 @jjm.command(name="apply")
+@click_option_target
 @click.pass_obj
-def jjm_apply(obj: JenkinsJobManager):
+def jjm_apply(obj: JenkinsJobManager, target: str):
     """check and apply changes"""
     check_auth(obj)
-    obj.gather()
+    obj.gather(target)
     handle_validation_errors(obj)
-    if not obj.detected_changes():
+    if obj.detected_changes() is False:
         click.secho("No changes to apply.", fg="green")
         return
     handle_plan_report(obj, use_pager=False)
@@ -166,10 +174,11 @@ def jjm_apply(obj: JenkinsJobManager):
 
 
 @jjm.command(name="import")
+@click_option_target
 @click.pass_obj
-def jjm_import(obj: JenkinsJobManager):
+def jjm_import(obj: JenkinsJobManager, target: str):
     check_auth(obj)
-    obj.gather()
+    obj.gather(target)
     missing = obj.import_missing()
     click.secho(f"Imported {len(missing)} jobs.", fg="green")
 
