@@ -9,6 +9,7 @@ from jenkins_job_manager.xml_change import (
 
 import itertools
 import logging
+import fnmatch
 import os
 import re
 import random
@@ -29,6 +30,28 @@ logging.basicConfig(level=logging.INFO)
 log = logging.getLogger("jjm")
 
 
+class NameRegexFilter:
+    """Regex Filter Callable"""
+
+    __slots__ = ("regex",)
+
+    def __init__(self, regexp):
+        self.regex = re.compile(regexp)
+
+    @staticmethod
+    def from_glob_list(globs):
+        regexes = map(fnmatch.translate, globs)
+        combined_regex = "|".join(regexes)
+        return NameRegexFilter(combined_regex)
+
+    def __call__(self, job_name):
+        m = self.regex.match(job_name)
+        return True if m is not None else False
+
+    def __repr__(self):
+        return f"{self.__class__.__name__}<{repr(self.regex)[11:-1]}>"
+
+
 class JenkinsJobManager:
     """main jjb manager"""
 
@@ -37,6 +60,7 @@ class JenkinsJobManager:
         "plugins_list",
         "_jenkins",
         "jobs",
+        "_jobs_filter_func",
         "views",
         "validation_errors",
     )
@@ -50,6 +74,7 @@ class JenkinsJobManager:
         self._jenkins: Optional[jenkins.Jenkins] = None
         self.plugins_list: Optional[list] = None
         self.jobs: Dict[str, XmlChange] = XmlChangeDefaultDict()
+        self._jobs_filter_func: NameRegexFilter = NameRegexFilter(".*")
         self.views: Dict[str, XmlChange] = XmlChangeDefaultDict()
         self.validation_errors = []
 
@@ -87,7 +112,10 @@ class JenkinsJobManager:
             log.debug("found job %r", d)
             name, url, _class = d["fullname"], d["url"], d.get("_class")
             subjobs = d.get("jobs", _empty)
-            if _class in self.job_managing_job_classes:
+            if not self._jobs_filter_func(name):
+                log.debug("Ignored by filter: %s", name)
+                continue
+            elif _class in self.job_managing_job_classes:
                 managed_job_urls.update(job_d["url"] for job_d in subjobs)
             elif url in managed_job_urls:
                 log.debug("Ignoring managed job %s", name)
@@ -188,7 +216,7 @@ class JenkinsJobManager:
                 return xml_job
 
         jjb_config = self.get_jjb_config()
-        options_names = []
+        options_names = []  # normally a list of jobs globs
         files_path = ["."]
 
         parser = YamlParser(jjb_config)
@@ -202,7 +230,12 @@ class JenkinsJobManager:
 
         job_data_list, view_data_list = parser.expandYaml(registry, options_names)
 
-        xml_jobs = xml_job_generator.generateXML(job_data_list)
+        def job_data_filter_wrapper(job_data):
+            return self._jobs_filter_func(job_data["name"])
+
+        xml_jobs = xml_job_generator.generateXML(
+            filter(job_data_filter_wrapper, job_data_list)
+        )
         jobs = self.jobs
         for xml_job in xml_jobs:
             formatted_xml_str = self.xml_dump(xml_job.xml)
@@ -219,8 +252,11 @@ class JenkinsJobManager:
             for item in itertools.chain(self.jobs.values(), self.views.values())
         )
 
-    def gather(self):
+    def gather(self, target_job_names=None):
         """run this to gather plan/apply data"""
+        if target_job_names:
+            log.debug("target_job_names=%r", target_job_names)
+            self._jobs_filter_func = NameRegexFilter.from_glob_list(target_job_names)
         self.read_jobs()
         self.load_plugins_list()
         self.generate_jjb_xml()
@@ -284,11 +320,10 @@ class JenkinsJobManager:
         def extract_md(job: XmlChange):
             node = ET.fromstring(job.after_xml)
             desc = node.find("./description")
-            if desc is None:
+            if desc is None or not desc.text:
                 log.warning("No description in jenkins job %r??", job.name)
                 return {}
-            text = desc.text
-            text = text.replace("<!-- Managed by Jenkins Job Builder -->", "")
+            text = desc.text.replace("<!-- Managed by Jenkins Job Builder -->", "")
             md = {
                 m.group(1): m.group(2)
                 for m in re.finditer(r"^\s*([\w-]+):\s*([\w -]+)\s*$", text, flags=re.M)
